==> bow-ui-1.0-sources.jar: org/chorem/bow/BowBookmark.java <==
package org.chorem.bow;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyLabel;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;


public interface BowBookmark extends BusinessEntity, WikittyLabel {     String EXT_BOWBOOKMARK = "BowBookmark";
     String FIELD_BOWBOOKMARK_LINK = "link";
     String FQ_FIELD_BOWBOOKMARK_LINK = EXT_BOWBOOKMARK + ".link";
     String FIELD_BOWBOOKMARK_DESCRIPTION = "description";
     String FQ_FIELD_BOWBOOKMARK_DESCRIPTION = EXT_BOWBOOKMARK + ".description";
     String FIELD_BOWBOOKMARK_CREATIONDATE = "creationDate";
     String FQ_FIELD_BOWBOOKMARK_CREATIONDATE = EXT_BOWBOOKMARK + ".creationDate";
     String FIELD_BOWBOOKMARK_CLICK = "click";
     String FQ_FIELD_BOWBOOKMARK_CLICK = EXT_BOWBOOKMARK + ".click";
     String FIELD_BOWBOOKMARK_PRIVATEALIAS = "privateAlias";
     String FQ_FIELD_BOWBOOKMARK_PRIVATEALIAS = EXT_BOWBOOKMARK + ".privateAlias";
     String FIELD_BOWBOOKMARK_PUBLICALIAS = "publicAlias";
     String FQ_FIELD_BOWBOOKMARK_PUBLICALIAS = EXT_BOWBOOKMARK + ".publicAlias";
     String FIELD_BOWBOOKMARK_BOWUSER = "bowUser";
     String FQ_FIELD_BOWBOOKMARK_BOWUSER = EXT_BOWBOOKMARK + ".bowUser";
    /**
     * getLink :
     * @return String 
     */

     String getLink();

    /**
     * setLink :
     * @param link 
     */

     void setLink(String link);

    /**
     * getDescription :
     * @return String 
     */

     String getDescription();

    /**
     * setDescription :
     * @param description 
     */

     void setDescription(String description);

    /**
     * getCreationDate :
     * @return Date 
     */

     Date getCreationDate();

    /**
     * setCreationDate :
     * @param creationDate 
     */

     void setCreationDate(Date creationDate);

    /**
     * getClick :
     * @return int 
     */

     int getClick();

    /**
     * setClick :
     * @param click 
     */

     void setClick(int click);

    /**
     * getPrivateAlias :
     * @return String 
     */

     String getPrivateAlias();

    /**
     * setPrivateAlias :
     * @param privateAlias 
     */

     void setPrivateAlias(String privateAlias);

    /**
     * getPublicAlias :
     * @return String 
     */

     String getPublicAlias();

    /**
     * setPublicAlias :
     * @param publicAlias 
     */

     void setPublicAlias(String publicAlias);

    /**
     * getBowUser :
     * @return String 
     */

     String getBowUser();

    /**
     * setBowUser :
     * @param bowUser 
     */

     void setBowUser(String bowUser);

    /**
     * getLabels :
     * @return Set<String> 
     */

     Set<String> getLabels();

    /**
     * setLabels :
     * @param labels 
     */

     void setLabels(Set<String> labels);

    /**
     * addAllLabels :
     * @param labels 
     */

     void addAllLabels(Set<String> labels);

    /**
     * addLabels :
     * @param element 
     */

     void addLabels(String element);

    /**
     * removeLabels :
     * @param element 
     */

     void removeLabels(String element);

    /**
     * clearLabels :
     */

     void clearLabels();


} //BowBookmark

==> bow-ui-1.1-sources.jar: org/chorem/bow/BowBookmark.java <==
package org.chorem.bow;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyAuthorisation;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyLabel;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;


public interface BowBookmark extends BusinessEntity, WikittyLabel, WikittyAuthorisation {     String EXT_BOWBOOKMARK = "BowBookmark";
     String FIELD_BOWBOOKMARK_LINK = "link";
     String FQ_FIELD_BOWBOOKMARK_LINK = EXT_BOWBOOKMARK + ".link";
     String FIELD_BOWBOOKMARK_DESCRIPTION = "description";
     String FQ_FIELD_BOWBOOKMARK_DESCRIPTION = EXT_BOWBOOKMARK + ".description";
     String FIELD_BOWBOOKMARK_CREATIONDATE = "creationDate";
     String FQ_FIELD_BOWBOOKMARK_CREATIONDATE = EXT_BOWBOOKMARK + ".creationDate";
     String FIELD_BOWBOOKMARK_CLICK = "click";
     String FQ_FIELD_BOWBOOKMARK_CLICK = EXT_BOWBOOKMARK + ".click";
     String FIELD_BOWBOOKMARK_PRIVATEALIAS = "privateAlias";
     String FQ_FIELD_BOWBOOKMARK_PRIVATEALIAS = EXT_BOWBOOKMARK + ".privateAlias";
     String FIELD_BOWBOOKMARK_PUBLICALIAS = "publicAlias";
     String FQ_FIELD_BOWBOOKMARK_PUBLICALIAS = EXT_BOWBOOKMARK + ".publicAlias";
     String FIELD_BOWBOOKMARK_AUTHENTIFICATIONINFO = "authentificationInfo";
     String FQ_FIELD_BOWBOOKMARK_AUTHENTIFICATIONINFO = EXT_BOWBOOKMARK + ".authentificationInfo";
    /**
     * getLink :
     * @return String 
     */

     String getLink();

    /**
     * setLink :
     * @param link 
     */

     void setLink(String link);

    /**
     * getDescription :
     * @return String 
     */

     String getDescription();

    /**
     * setDescription :
     * @param description 
     */

     void setDescription(String description);

    /**
     * getCreationDate :
     * @return Date 
     */

     Date getCreationDate();

    /**
     * setCreationDate :
     * @param creationDate 
     */

     void setCreationDate(Date creationDate);

    /**
     * getClick :
     * @return int 
     */

     int getClick();

    /**
     * setClick :
     * @param click 
     */

     void setClick(int click);

    /**
     * getPrivateAlias :
     * @return String 
     */

     String getPrivateAlias();

    /**
     * setPrivateAlias :
     * @param privateAlias 
     */

     void setPrivateAlias(String privateAlias);

    /**
     * getPublicAlias :
     * @return String 
     */

     String getPublicAlias();

    /**
     * setPublicAlias :
     * @param publicAlias 
     */

     void setPublicAlias(String publicAlias);

    /**
     * getAuthentificationInfo :
     * @return String 
     */

     String getAuthentificationInfo();

    /**
     * setAuthentificationInfo :
     * @param authentificationInfo 
     */

     void setAuthentificationInfo(String authentificationInfo);

    /**
     * getLabels :
     * @return Set<String> 
     */

     Set<String> getLabels();

    /**
     * setLabels :
     * @param labels 
     */

     void setLabels(Set<String> labels);

    /**
     * addAllLabels :
     * @param labels 
     */

     void addAllLabels(Set<String> labels);

    /**
     * addLabels :
     * @param element 
     */

     void addLabels(String element);

    /**
     * removeLabels :
     * @param element 
     */

     void removeLabels(String element);

    /**
     * clearLabels :
     */

     void clearLabels();

    /**
     * getOwner :
     * @return String 
     */

     String getOwner();

    /**
     * setOwner :
     * @param owner 
     */

     void setOwner(String owner);

    /**
     * getAdmin :
     * @return Set<String> 
     */

     Set<String> getAdmin();

    /**
     * setAdmin :
     * @param admin 
     */

     void setAdmin(Set<String> admin);

    /**
     * addAllAdmin :
     * @param admin 
     */

     void addAllAdmin(Set<String> admin);

    /**
     * addAdmin :
     * @param element 
     */

     void addAdmin(String element);

    /**
     * removeAdmin :
     * @param element 
     */

     void removeAdmin(String element);

    /**
     * clearAdmin :
     */

     void clearAdmin();

    /**
     * getWriter :
     * @return Set<String> 
     */

     Set<String> getWriter();

    /**
     * setWriter :
     * @param writer 
     */

     void setWriter(Set<String> writer);

    /**
     * addAllWriter :
     * @param writer 
     */

     void addAllWriter(Set<String> writer);

    /**
     * addWriter :
     * @param element 
     */

     void addWriter(String element);

    /**
     * removeWriter :
     * @param element 
     */

     void removeWriter(String element);

    /**
     * clearWriter :
     */

     void clearWriter();

    /**
     * getReader :
     * @return Set<String> 
     */

     Set<String> getReader();

    /**
     * setReader :
     * @param reader 
     */

     void setReader(Set<String> reader);

    /**
     * addAllReader :
     * @param reader 
     */

     void addAllReader(Set<String> reader);

    /**
     * addReader :
     * @param element 
     */

     void addReader(String element);

    /**
     * removeReader :
     * @param element 
     */

     void removeReader(String element);

    /**
     * clearReader :
     */

     void clearReader();

    /**
     * getParent :
     * Pointe sur un autre WikittyAuthorisation qui permet d'indiquer que les droits de l'objet courant sont les mêmes que l'objet pointée. Les droits de l'objet courant s'ajoute au droit de l'objet pointé
     * @return String 
     */

     String getParent();

    /**
     * setParent :
     * @param parent 
     */

     void setParent(String parent);


} //BowBookmark
